Documentation
¶
Overview ¶
Package merge implements PO file merging logic, equivalent to the msgmerge utility.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Merge ¶
Merge updates a PO file with entries from a POT template. - New entries from the template are added with empty translations. - Existing entries that are still in the template are kept. - Entries that are no longer in the template are marked obsolete. - References and flags are updated from the template.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.